@@ -131,7 +131,7 @@ class apm(dbus.service.Object):
     try:
       c_signal = self.__signals[key]['obj']
       self.__bus.remove_signal_receiver(c_signal)
-      self.__bus.clean_up_signal_match(c_signal)
+      #self.__bus.clean_up_signal_match(c_signal)
       c_signal.remove()
       self.__signals[key].pop('obj')
     except KeyError:
