@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 '''
 Advanced Power Monitor Daemon
-2009(c) Kirill Plyashkevich <ru.spirit@gmail.ru>
-Works as daemon extending AbstractDaemon and creating Advanced Power Monitor.
+2010(c) Kirill Plyashkevich <ru.spirit@gmail.ru>
+Works as daemon creating Advanced Power Monitor.
 '''
-import sys, gobject, signal
+import gobject, signal
 import AdvancedPowerMonitor
 
 class apmd():
