@@ -9,7 +9,7 @@ class BatteryDummy(AbstractBattery):
 
   def pre_init(self):
     self.friendly_name = 'Dummy'
-    self.dep_packages = {'advanced-power-monitor': '0.5.1'}
+    self.depends['packages'] = {'advanced-power-monitor': '0.5.1'}
     self.interfaces_map = {}
     self.export_signals = {'battery_charger_is_connected': {},
                            'battery_charger_is_disconnected': {},
